@@ -22,7 +22,7 @@ fn can_solve_problem_using_full_config() {
         termination.max_generations = Some(1);
     }
 
-    let (solution, _, _) = create_builder_from_config(problem.clone(), &config)
+    let (solution, _, _) = create_builder_from_config(problem.clone(), Default::default(), &config)
         .unwrap()
         .build()
         .map(|config| Solver::new(problem.clone(), config))
